@@ -7,6 +7,12 @@ class RequirementsClass:
 
 
 @Requirements("REQ_333")
-def requirements_function():
+def requirements_function() -> None:
     # Test function for Requirements decorator
     pass
+
+
+@Requirements("REQ_444")
+async def asyncrequirements_function() -> None:
+    # Test async function for Requirements decorator
+    pass
